pub enum DataSource {
RrdHttpUrl {
uri: String,
follow: bool,
},
FilePath(FileSource, PathBuf),
FileContents(FileSource, FileContents),
Stdin,
RerunGrpcStream {
uri: RedapUri,
select_when_loaded: bool,
},
}Expand description
Somewhere we can get Rerun data from.
Variants
RrdHttpUrl
A remote RRD file, served over http.
Could be either an .rrd recording or a .rbl blueprint.
Fields
FilePath(FileSource, PathBuf)
A path to a local file.
FileContents(FileSource, FileContents)
The contents of a file.
This is what you get when loading a file on Web, or when using drag-n-drop.
Stdin
RerunGrpcStream
A rerun:// URI pointing to a recording or catalog.
Implementations
Sourceimpl DataSource
impl DataSource
Sourcepub fn from_uri(_file_source: FileSource, uri: String) -> Self
pub fn from_uri(_file_source: FileSource, uri: String) -> Self
Tried to classify a URI into a DataSource.
Tries to figure out if it looks like a local path, a web-socket address, or a http url.
pub fn file_name(&self) -> Option<String>
pub fn is_blueprint(&self) -> Option<bool>
Sourcepub fn stream(
self,
connection_registry: &ConnectionRegistryHandle,
on_cmd: Box<dyn Fn(DataSourceCommand) + Send + Sync>,
on_msg: Option<Box<dyn Fn() + Send + Sync>>,
) -> Result<StreamSource>
pub fn stream( self, connection_registry: &ConnectionRegistryHandle, on_cmd: Box<dyn Fn(DataSourceCommand) + Send + Sync>, on_msg: Option<Box<dyn Fn() + Send + Sync>>, ) -> Result<StreamSource>
Stream the data from the given data source.
Will do minimal checks (e.g. that the file exists), for synchronous errors, but the loading is done in a background task.
on_cmd is used to respond to UI commands.
on_msg can be used to wake up the UI thread on Wasm.