pub enum LogDataSource {
HttpUrl {
url: Url,
follow: bool,
},
FilePath {
file_source: FileSource,
path: PathBuf,
follow: bool,
},
FileContents(FileSource, FileContents),
Stdin,
RedapDatasetSegment {
uri: DatasetSegmentUri,
select_when_loaded: bool,
},
RedapProxy(ProxyUri),
}Expand description
Somewhere we can get Rerun logging data from.
Variants
HttpUrl
A remote file, served over http.
Could be an .rrd recording, .rbl blueprint, .mcap, .png, .glb, etc.
Fields
FilePath
A path to a local file.
Fields
file_source: FileSourceHow we got to know about the file
FileContents(FileSource, FileContents)
The contents of a file.
This is what you get when loading a file on Web, or when using drag-n-drop.
Stdin
RedapDatasetSegment
A rerun:// URI pointing to a recording.
Fields
uri: DatasetSegmentUriRedapProxy(ProxyUri)
A rerun+http:// URI pointing to a proxy.
Implementations
Sourceimpl LogDataSource
impl LogDataSource
Sourcepub fn from_uri(
_file_source: FileSource,
url: &str,
follow: bool,
) -> Option<Self>
pub fn from_uri( _file_source: FileSource, url: &str, follow: bool, ) -> Option<Self>
Tries to classify a URI into a LogDataSource.
Tries to figure out if it looks like a local path, a web-socket address, a grpc url, a http url, etc.
Note that not all URLs are log data sources! For instance a pure server or entry url is not a source of log data.
Sourcepub fn stream(
self,
on_auth_err: AuthErrorHandler,
connection_registry: &ConnectionRegistryHandle,
) -> Result<LogReceiver>
pub fn stream( self, on_auth_err: AuthErrorHandler, connection_registry: &ConnectionRegistryHandle, ) -> Result<LogReceiver>
Stream the data from the given data source.
Will do minimal checks (e.g. that the file exists), for synchronous errors, but the loading is done in a background task.
on_redap_err should handle authentication errors by showing a login prompt.
Sourcepub fn analytics(&self) -> LogDataSourceAnalytics
pub fn analytics(&self) -> LogDataSourceAnalytics
Returns analytics data for this data source.